RuleSnapshot

Struct RuleSnapshot 

pub struct RuleSnapshot {
Show 21 fields pub i: usize, pub d: usize, pub name: RuleName, pub spec: Arc<RuleSpec>, pub state: RuleState, pub bo: bool, pub ao: bool, pub bc: bool, pub ac: bool, pub need: i32, pub node: Rc<RefCell<Value>>, pub parent_rule: Option<Rc<RuleSnapshot>>, pub child_rule: Option<Rc<RuleSnapshot>>, pub prev_rule: Option<Rc<RuleSnapshot>>, pub next_rule: Option<Rc<RuleSnapshot>>, pub next_rule_name: Option<RuleName>, pub n: Rc<HashMap<String, i32>>, pub u: Rc<HashMap<String, Value>>, pub k: Rc<HashMap<String, Value>>, pub o: Rc<Vec<Token>>, pub c: Rc<Vec<Token>>,
}

Fields

i: usized: usizename: RuleNamespec: Arc<RuleSpec>state: RuleStatebo: boolao: boolbc: boolac: boolneed: i32node: Rc<RefCell<Value>>parent_rule: Option<Rc<RuleSnapshot>>child_rule: Option<Rc<RuleSnapshot>>prev_rule: Option<Rc<RuleSnapshot>>next_rule: Option<Rc<RuleSnapshot>>next_rule_name: Option<RuleName>n: Rc<HashMap<String, i32>>u: Rc<HashMap<String, Value>>k: Rc<HashMap<String, Value>>o: Rc<Vec<Token>>

Matched open and close tokens. Shared rather than owned: the parse loop only ever replaces these wholesale, and a snapshot that copied them copied every Token’s name and source text with them.

c: Rc<Vec<Token>>