AltModifier

Type Alias AltModifier 

pub type AltModifier = Arc<dyn Fn(AltSpec, &mut Rule, &mut Context) -> AltSpec + Send + Sync>;
Post-match alternate modifier. It takes and returns the effective match so replacement is explicit rather than mutating shared grammar state.

Aliased Type

pub struct AltModifier { /* private fields */ }