pub fn deep(base: Value, overlays: impl IntoIterator<Item = Value>) -> ValueExpand description
Recursively merge JSON data. Objects merge by key, arrays by index, and unlike container kinds or scalar values are replaced by the overlay.
pub fn deep(base: Value, overlays: impl IntoIterator<Item = Value>) -> ValueRecursively merge JSON data. Objects merge by key, arrays by index, and unlike container kinds or scalar values are replaced by the overlay.